@@ -9,6 +9,7 @@ require(DT)
 require(data.table)
 require(difNLR)
 require(difR)
+require(dplyr)
 require(ggdendro)
 require(ggplot2)
 require(grid)
@@ -30,9 +31,11 @@ require(shinyBS)
 require(ShinyItemAnalysis)
 require(shinyjs)
 require(stringr)
+require(tibble)
 require(VGAM)
 require(xtable)
 
+
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 # DATA ######
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -45,6 +48,8 @@ options(shiny.maxRequestSize = 30*1024^2)
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 function(input, output, session) {
+  # kills the local server as the window closes
+  # session$onSessionEnded(function(x) {stopApp()})
 
   #%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   ### REACTIVE VALUES ######
@@ -234,7 +239,8 @@ function(input, output, session) {
       inputData <- read.csv(input$data$datapath,
                             header = input$header,
                             sep = input$sep,
-                            quote = input$quote)
+                            quote = input$quote,
+                            stringsAsFactors = TRUE)
       dataset$data_status <- "OK"
 
       # loading max/min values for ordinal data
@@ -461,6 +467,10 @@ function(input, output, session) {
     dataset$criterion
   })
 
+  crit_wo_val <- reactive({
+    dataset$criterion
+  })
+
   DIFmatching <- reactive({
     ### bad DIF matching dimension and warning for missing DIF matching variable
     if (length(dataset$DIFmatching) == 1 & any(dataset$DIFmatching == "missing")) {
@@ -546,6 +556,9 @@ function(input, output, session) {
       "zlogreg_irtSlider",
       "slider_nlr_3P_item",
       "slider_nlr_4P_item",
+      "cumreg_slider_item",
+      "adjreg_slider_item",
+      "multi_slider_item",
       "DIF_NLR_item_plot",
       "difirt_lord_itemSlider",
       "difirt_raju_itemSlider",
@@ -566,6 +579,9 @@ function(input, output, session) {
     updateSliderInput(session = session, inputId = "zlogreg_irtSlider", max = itemCount)
     updateSliderInput(session = session, inputId = "slider_nlr_3P_item", max = itemCount)
     updateSliderInput(session = session, inputId = "slider_nlr_4P_item", max = itemCount)
+    updateSliderInput(session = session, inputId = "cumreg_slider_item", max = itemCount)
+    updateSliderInput(session = session, inputId = "adjreg_slider_item", max = itemCount)
+    updateSliderInput(session = session, inputId = "multi_slider_item", max = itemCount)
     updateSliderInput(session = session, inputId = "DIF_NLR_item_plot", max = itemCount)
     updateSliderInput(session = session, inputId = "difirt_lord_itemSlider", max = itemCount)
     updateSliderInput(session = session, inputId = "difirt_raju_itemSlider", max = itemCount)
@@ -829,11 +845,9 @@ function(input, output, session) {
         isGroupPresent = groupPresent(),
         ### histograms by group
         histCheck = input$histCheck,
-        resultsgroup = {if (groupPresent()) {if (input$histCheck) {resultsgroupInput()}}},
-        cutScoregroup = input$inSlider2group,
-        histbyscoregroup0 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup0Input()}}},
-        histbyscoregroup1 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup1Input()}}},
-        DIF_scores_ttest = {if (groupPresent()) {if (input$histCheck) {DIF_scores_ttest_Input()}}},
+        DIF_total_table = {if (groupPresent()) {if (input$histCheck) {DIF_total_table_Input()}}},
+        DIF_total_hist = {if (groupPresent()) {if (input$histCheck) {DIF_total_hist_Input()}}},
+        DIF_total_ttest = {if (groupPresent()) {if (input$histCheck) {DIF_total_ttest_Input()}}},
         ### delta plot
         deltaplotCheck = input$deltaplotCheck,
         deltaplot = {if (groupPresent()) {if (input$deltaplotCheck) {deltaplotInput_report()}}},
@@ -919,11 +933,9 @@ function(input, output, session) {
         isGroupPresent = groupPresent(),
         ### histograms by groups
         histCheck = input$histCheck,
-        resultsgroup = {if (groupPresent()) {if (input$histCheck) {resultsgroupInput()}}},
-        cutScoregroup = input$inSlider2group,
-        histbyscoregroup0 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup0Input()}}},
-        histbyscoregroup1 = {if (groupPresent()) {if (input$histCheck) {histbyscoregroup1Input()}}},
-        DIF_scores_ttest = {if (groupPresent()) {if (input$histCheck) {DIF_scores_ttest_Input()}}},
+        DIF_total_table = {if (groupPresent()) {if (input$histCheck) {DIF_total_table_Input()}}},
+        DIF_total_hist = {if (groupPresent()) {if (input$histCheck) {DIF_total_hist_Input()}}},
+        DIF_total_ttest = {if (groupPresent()) {if (input$histCheck) {DIF_total_ttest_Input()}}},
         ### delta plot
         deltaplotCheck = input$deltaplotCheck,
         DIF_deltaplot = {if (groupPresent()) {if (input$deltaplotCheck) {deltaplotInput_report()}}},
