@@ -22,7 +22,7 @@ output$DDplot_text <- renderUI({
 
   if (any(range1 != 1, range2 != 3, input$DDplotNumGroupsSlider != 3)) {
     HTML(paste(
-      "Discrimination is here a difference between the difficulty recorded in the ",
+      "Discrimination is defined as a difference in average (scaled) item score between the ",
       "<b>", range1, "</b>",
       ifelse(range1 >= 4, "-th", switch(range1, "1" = "-st", "2" = "-nd", "3" = "-rd")),
       " and <b>", range2, "</b>",
@@ -50,11 +50,12 @@ DDplot_Input <- reactive({
          k = input$DDplotNumGroupsSlider,
          l = input$DDplotRangeSlider[[1]], u = input$DDplotRangeSlider[[2]],
          discrim = input$DDplotDiscriminationSelect,
-         average.score = average.score)
+         average.score = average.score,
+         thr = switch(input$DDplotThr_cb, "TRUE" = input$DDplotThr, "FALSE" = NULL))
 })
 
-# ** Difficulty/Discrimination plot for report######
-DDplot_Input_report<-reactive({
+# ** Difficulty/Discrimination plot for report ######
+DDplot_Input_report <- reactive({
   correct <- ordinal()
   if (input$customizeCheck) {
 
@@ -70,9 +71,30 @@ DDplot_Input_report<-reactive({
   }
 })
 
-# ** Output Difficulty/Discrimination plot ######
-output$DDplot <- renderPlot({
-  DDplot_Input()
+# ** Output for Diif/Disr. plot with plotly ######
+output$DDplot <- renderPlotly({
+  p <- DDplot_Input() %>%
+    ggplotly(tooltip = c("item", "fill", "value", "yintercept"))
+
+  # renaming/removing unnecessary text
+  for (i in 1:2) {
+    for (j in 1:length(p$x$data[[i]][["text"]])) {
+      p$x$data[[i]][["text"]][j]  <-
+        str_remove(str_replace(
+          str_remove_all(p$x$data[[i]][["text"]][j], "parameter: |value: "),
+          "item",
+          "Item"
+        ),
+        "(?<=\\.\\d{3}).*")
+    }
+  }
+
+  if (input$DDplotThr_cb == TRUE) {
+    p$x$data[[3]][["text"]] <-
+      str_replace(p$x$data[[3]][["text"]], "yintercept", "Threshold")
+  }
+
+  p %>% plotly::config(displayModeBar = F)
 })
 
 # ** DB Difficulty/Discrimination plot ######
@@ -89,74 +111,146 @@ output$DB_DDplot <- downloadHandler(
   }
 )
 
-# ** Cronbach's alpha table ######
-cronbachalpha_table_Input <- reactive({
-  correct <- ordinal()
-  tab <- c(psych::alpha(correct)$total[1], psych::alpha(correct)$total[8])
+# ** Cronbach's alpha note ######
 
-  tab <- as.data.table(tab)
-  colnames(tab) <- c("Estimate", "SD")
+cronbach_note <- reactive({
+  cronbach <- NULL
 
-  tab
+  cronbach$est <- round(psych::alpha(ordinal())$total[1], 2)
+
+  cronbach$sd <- round(psych::alpha(ordinal())$total[8], 2)
+
+  cronbach
 })
 
-# ** Output Cronbach's alpha table ######
-output$cronbachalpha_table <- renderTable({
-  cronbachalpha_table_Input()
-},
-include.rownames = F,
-include.colnames = T)
-
-# ** Traditional item analysis table text ######
-output$itemanalysis_table_text <- renderUI({
-  range1 <- input$DDplotRangeSlider[[1]]
-  range2 <- input$DDplotRangeSlider[[2]]
-  num.groups <- input$DDplotNumGroupsSlider
-  HTML(paste(
-    " <b> Explanation: Difficulty </b> ",
-    " - difficulty of the item is estimated as its average score divided by its range, ",
-    " <b> Average score </b> ",
-    " - average score of the item, ",
-    " <b> SD </b> ",
-    " - standard deviation, ",
-    " <b> RIT </b> ",
-    " - Pearson correlation between item and total score, ",
-    " <b> RIR </b> ",
-    " - Pearson correlation between item and rest of items, ",
-    " <b> ULI </b> ",
-    " - Upper-Lower Index, ",
-    " <b> Alpha Drop </b> ",
-    " - Cronbach\'s alpha of test without given item, ",
-    " <b> Customized Discrimination </b> ",
-    " - difference between the difficulty recorded in the ", range1,
-    ifelse(range1 >= 4, "-th", switch(range1, "1" = "-st", "2" = "-nd", "3" = "-rd")),
-    " and ", range2,
-    ifelse(range2 >= 4, "-th", switch(range2, "1" = "-st", "2" = "-nd", "3" = "-rd")),
-    " group out of total number of ", num.groups, " groups. ",
-    sep = ""
+output$cronbach_note <- renderUI({
+  withMathJax(HTML(
+    paste0(
+      "<sup>1</sup>Estimate (SD) of Cronbach's $\\alpha$ for the test as a whole is: ",
+      cronbach_note()$est,
+      " (",
+      cronbach_note()$sd,
+      ")."
+    )
   ))
 })
 
-# ** Traditional item analysis table ######
-itemanalysis_table_Input <- reactive({
-  a <- nominal()
-  k <- key()
-  correct <- ordinal()
-  num.groups <- input$DDplotNumGroupsSlider
+
+# ** Traditional item analysis table text ######
+output$itemanalysis_table_text <- renderUI({
+
   range1 <- input$DDplotRangeSlider[[1]]
   range2 <- input$DDplotRangeSlider[[2]]
+  num.groups <- input$DDplotNumGroupsSlider
+  withMathJax(HTML(paste0(
+    "<b>Explanation:<br>Diff.</b>&nbsp;",
+    "&ndash; item difficulty estimated as average item score divided by its range, ",
+    "<b>Avg. score</b>&nbsp;",
+    "&ndash; average item score, ",
+    "<b>SD</b>&nbsp;",
+    "&ndash; standard deviation, ",
+    "<b>RIT</b>&nbsp;",
+    "&ndash; Pearson correlation between item and total score, ",
+    "<b>RIR</b>&nbsp;",
+    "&ndash; Pearson correlation between item and rest of items, ",
+    "<b>ULI</b>&nbsp;",
+    "&ndash; Upper-Lower Index, ",
+    "<b>$\\alpha$ drop </b>&nbsp;",
+    "&ndash; Cronbach\'s $\\alpha$ of test without given item (the value for the test as a whole is presented in the note below), ",
+    if (num.groups != 3 | range1 != 1 | range2 != 3) {
+      paste0("<b>gULI</b>&nbsp;",
+      "&ndash; generalized ULI, difference between the difficulty recorded in the ", range1,
+      ifelse(range1 >= 4, "-th", switch(range1, "1" = "-st", "2" = "-nd", "3" = "-rd")),
+      " and ", range2,
+      ifelse(range2 >= 4, "-th", switch(range2, "1" = "-st", "2" = "-nd", "3" = "-rd")),
+      " group out of total number of ", num.groups, " groups, ")
+    },
+    "<b>Rel.</b>&nbsp;",
+    "&ndash; item reliability index, see Allen & Yen (1979; Ch. 6.4), ",
+    "<b>Rel. drop</b>&nbsp;",
+    "&ndash; as previous, but scored without the respective item, ",
+    "<b>I-C cor.</b>&nbsp;",
+    "&ndash; item-criterion correlation, ",
+    "<b>Val. index</b>&nbsp;",
+    "&ndash; validity index, as described by Allen & Yen (1979; Ch. 6.4), ",
+    "<b>Missed</b>&nbsp;",
+    "&ndash; proportion of missed responses on the particular item, ",
+    "<b>Not-reached</b>&nbsp;",
+    "&ndash; proportion of respondents that did not reached the item nor the subsequent ones"
+  )))
+})
+
+
+# ** Traditional item analysis table - revised ######
+itemanalysis_table_Input <- reactive({
+  k <- input$DDplotNumGroupsSlider
+  l <- input$DDplotRangeSlider[[1]]
+  u <- input$DDplotRangeSlider[[2]]
+
+  item_crit_cor <- if (any(crit_wo_val() == "missing", na.rm = TRUE)) {
+    NULL
+  } else {
+    unlist(crit_wo_val())
+  }
+
+  tab <-
+    ItemAnalysis(ordinal(),
+                 y = item_crit_cor,
+                 k, l, u)
+
+  # rename colnames
+  colnames(tab) <- c(
+    "Diff.",
+    "Avg. score",
+    "SD",
+    "min",
+    "max",
+    "obtMin",
+    "obtMax",
+    "cutScore",
+    "gULI",
+    "ULI",
+    "RIT",
+    "RIR",
+    "I-C cor.",
+    "Val. index",
+    "Rel.",
+    "Rel. drop",
+    "Alpha drop",
+    "Missed [%]",
+    "Not-reached [%]"
+  )
+
+  # prepare cols selection
+  ia_sel_vars <- c(
+    "Diff.",
+    "Avg. score",
+    "SD",
+    "ULI",
+    if (k != 3 | l != 1 | u != 3) {
+      "gULI"
+    },
+    "RIT",
+    "RIR",
+    "Alpha drop",
+    "Rel.",
+    "Rel. drop",
+    if (!is.null(item_crit_cor)) {
+      c("I-C cor.",
+        "Val. index")
+    },
+    "Missed [%]",
+    "Not-reached [%]"
+  )
+
+  tab <- tab[, ia_sel_vars]
+
+  row.names(tab) <- item_names()
 
-  alphadrop <- psych::alpha(correct)$alpha.drop[, 1]
-  tab <- ItemAnalysis(correct)
-  tab <- data.table(item_numbers(),
-                    tab[, c('Difficulty', 'Average score', 'SD', 'ULI default', 'RIT', 'RIR','Alpha drop')])
-  tab <- cbind(tab, gDiscrim(correct, k = num.groups, l = range1, u = range2))
-  colnames(tab) <- c("Item", "Difficulty", "Average score", "SD", "Discrimination ULI",
-                     "Discrimination RIT", "Discrimination RIR", "Alpha Drop",
-                     "Customized Discrimination")
   tab
 })
 
+
 # ** Traditional item analysis table for report ######
 itemanalysis_table_report_Input <- reactive({
   a <- nominal()
@@ -173,10 +267,9 @@ itemanalysis_table_report_Input <- reactive({
                        input$DDplotNumGroupsSlider_report,
                        input$DDplotNumGroupsSlider)
 
-  alphadrop <- psych::alpha(correct)$alpha.drop[, 1]
   tab <- ItemAnalysis(correct)
   tab <- data.table(item_numbers(),
-                    tab[, c('Difficulty', 'Average score', 'SD', 'ULI default', 'RIT', 'RIR','Alpha drop')])
+                    tab[, c('diff', 'avgScore', 'SD', 'ULI', 'RIT', 'RIR', 'alphaDrop')])
   tab <- cbind(tab, gDiscrim(correct, k = num.groups, l = range1, u = range2))
   colnames(tab) <- c("Item", "Difficulty", "Average score", "SD", "Discrimination ULI",
                      "Discrimination RIT", "Discrimination RIR", "Alpha Drop",
@@ -184,11 +277,13 @@ itemanalysis_table_report_Input <- reactive({
   tab
 })
 
+
 # ** Output traditional item analysis table ######
-output$itemanalysis_table <- renderTable({
-  itemanalysis_table_Input()
-},
-include.rownames = FALSE)
+output$coef_itemanalysis_table <- renderTable({
+  tab <- itemanalysis_table_Input()
+  colnames(tab)[which(colnames(tab) == "Alpha drop")] <- "%%mathit{\\alpha}%% drop%%mathit{\\mathrm{^1}}%%"
+  tab
+}, rownames = TRUE)
 
 
 # ** Download traditional item analysis table ######
@@ -198,7 +293,18 @@ output$download_itemanal_table <- downloadHandler(
   },
   content = function(file) {
     data <- itemanalysis_table_Input()
-    write.csv(data,file)
+    write.csv(data, file)
+    write(
+      paste0(
+        "Note: Estimate (SD) of Cronbach's alpha for the test as a whole is: ",
+        cronbach_note()$est,
+        " (",
+        cronbach_note()$sd,
+        ")."
+      ),
+      file,
+      append = T
+    )
   }
 )
 
@@ -302,9 +408,11 @@ distractor_table_counts_Input <- reactive({
   sc <- total_score()
 
   DA <- DistractorAnalysis(a, k, num.groups = num.group,matching = sc)[[item]]
-  df <- dcast(as.data.frame(DA), response ~ score.level, sum, margins = T, value.var = "Freq")
+  # df <- dcast(as.data.frame(DA), response ~ score.level, sum, margins = T, value.var = "Freq")
+  df <- DA %>% addmargins %>% as.data.frame.matrix %>% add_column(.before = 1, Response = as.factor(rownames(.)))
   colnames(df) <- c("Response", paste("Group", 1:ifelse(num.group > (ncol(df) - 2), ncol(df) - 2, num.group)), "Total")
   levels(df$Response)[nrow(df)] <- "Total"
+  rownames(df) <- NULL
   df
 })
 
@@ -322,8 +430,10 @@ distractor_table_proportions_Input <- reactive({
   sc <- total_score()
 
   DA <- DistractorAnalysis(a, k, num.groups = num.group, p.table = TRUE, matching = sc)[[item]]
-  df <- dcast(as.data.frame(DA), response ~ score.level, sum, value.var = "Freq")
+  # df <- dcast(as.data.frame(DA), response ~ score.level, sum, value.var = "Freq")
+  df <- DA %>% as.data.frame.matrix %>% add_column(.before = 1, Response = as.factor(rownames(.)))
   colnames(df) <- c("Response", paste("Group", 1:ifelse(num.group > (ncol(df) - 1), ncol(df) - 1, num.group)))
+  rownames(df) <- NULL
   df
 })
 
@@ -341,8 +451,10 @@ distractor_barplot_item_response_patterns_Input <- reactive({
   sc <- total_score()
 
   DA <- DistractorAnalysis(a, k, num.groups = num.group, p.table = TRUE, matching = sc)[[item]]
-  df <- dcast(as.data.frame(DA), response ~ score.level, sum, value.var = "Freq")
+  # df <- dcast(as.data.frame(DA), response ~ score.level, sum, value.var = "Freq")
+  df <- DA %>% as.data.frame.matrix %>% add_column(.before = 1, Response = as.factor(rownames(.)))
   colnames(df) <- c("Response", "Proportion")
+  rownames(df) <- NULL
 
   ggplot(df, aes(x = Response, y = Proportion)) +
     geom_bar(stat = "identity") +
